/***********************************************************************************************************************
 *
 * blueMarine Semantic - open source media workflow
 * Copyright (C) 2008-2011 by Tidalwave s.a.s. (http://www.tidalwave.it)
 *
 ***********************************************************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations under the License.
 *
 ***********************************************************************************************************************
 *
 * WWW: http://bluemarine.tidalwave.it
 * SCM: https://kenai.com/hg/bluemarine~semantic-src
 *
 **********************************************************************************************************************/
package it.tidalwave.semantic.importexport;

import java.io.IOException;
import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.net.URI;
import java.net.URISyntaxException;
import org.jdesktop.beansbinding.BindingGroup;
import it.tidalwave.util.logging.Logger;
import it.tidalwave.netbeans.util.Locator;
import it.tidalwave.semantic.other.Repository;
import it.tidalwave.semantic.other.SemanticFactory;
import it.tidalwave.semantic.io.SemanticMarshaller;
import it.tidalwave.semantic.io.SemanticMarshaller.Configuration;
import it.tidalwave.semantic.openrdf.OpenRDFSemanticFactory;
import it.tidalwave.semantic.persistence.NoSuchContextException;
import it.tidalwave.semantic.persistence.SemanticPersistence;

/*******************************************************************************
 *
 * @author  Fabrizio Giudici
 * @version $Id: ExportTargetSelectionController.java,v 4fbb06e9364c 2011/03/06 21:25:16 fabrizio $
 *
 ******************************************************************************/
public class ExportTargetSelectionController extends AbstractSelectionController
  {
    private final static String CLASS = ExportTargetSelectionController.class.getName();
    private final static Logger logger = Logger.getLogger(CLASS);

    /***************************************************************************
     *
     *
     **************************************************************************/
    public void doExport()
      throws NoSuchContextException, IOException, URISyntaxException
      {
        logger.fine("doExport()");

        OutputStream outputStream = null;

        try
          {
            URI uri = null;
            final String mimeType = getUrlMIMEType();
            final SemanticPersistence semanticPersistence = Locator.find(SemanticPersistence.class);
            final OpenRDFSemanticFactory semanticFactory = OpenRDFSemanticFactory.Locator.findSemanticFactory();
            final Repository repository = semanticFactory.createDelegatingRepository(semanticPersistence.findRepositoryByName("DEFAULT"));
                    
            final SemanticMarshaller marshaller = repository.getMarshaller();

                final File file = new File(getFile());
                uri = file.toURI();
                logger.finer(">>>> writing to file: %s - uri: %s - MIME type: %s", file.getAbsolutePath(), uri, mimeType);
                outputStream = new FileOutputStream(file);

            if (outputStream != null)
              {
                final BindingGroup bindings = new BindingGroup();
//                bindings.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
//                                                               outputStream,
//                                                               BeanProperty.create(outputStream.PROP_PROCESSED_BYTE_COUNT),
//                                                               this,
//                                                               BeanProperty.create(this.PROP_PROGRESSCOUNT)));
//                bindings.addBinding(Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
//                                                               outputStream,
//                                                               BeanProperty.create(outputStream.PROP_TOTAL_BYTE_COUNT),
//                                                               this,
//                                                               BeanProperty.create(this.PROP_SIZE)));
                bindings.bind();
                final Writer writer = new OutputStreamWriter(outputStream);
                marshaller.marshal(writer, mimeType, Configuration.DEFAULT);
                bindings.unbind(); // FIXME: finally
              }
          }
        finally
          {
            if (outputStream != null)
              {
                try
                  {
                    outputStream.close();
                  }
                catch (IOException e)
                  {
                    logger.throwing(CLASS, "doImport()", e);
                  }
              }
          }
      }
  }
